@@ -1,6 +1,5 @@
 # Apache 2 header omitted for brevity
 
-from openstack.fake import fake_service
 from openstack import resource
 
 
@@ -8,11 +7,10 @@ class Fake(resource.Resource):
     resource_key = "resource"
     resources_key = "resources"
     base_path = "/fake"
-    service = fake_service.FakeService()
 
     allow_create = True
-    allow_get = True
-    allow_update = True
+    allow_fetch = True
+    allow_commit = True
     allow_delete = True
     allow_list = True
     allow_head = True
