@@ -22,7 +22,8 @@ def delete_network(conn):
     print("Delete Network:")
 
     example_network = conn.network.find_network(
-        'openstacksdk-example-project-network')
+        'openstacksdk-example-project-network'
+    )
 
     for example_subnet in example_network.subnet_ids:
         conn.network.delete_subnet(example_subnet, ignore_missing=False)
