@@ -12,7 +12,6 @@
 
 import collections
 import enum
-import typing as ty
 import warnings
 
 from keystoneauth1 import adapter
@@ -212,7 +211,7 @@ class Node(_common.Resource):
     #: unit of a specific type of resource. Added in API microversion 1.21.
     resource_class = resource.Body("resource_class")
     #: A string representing the current service step being executed upon.
-    #: Added in API microversion 1.87.
+    #: Added in API microversion 1.89.
     service_step = resource.Body("service_step")
     #: A string representing the uuid or logical name of a runbook as an
     #: alternative to providing ``clean_steps`` or ``service_steps``.
@@ -334,7 +333,7 @@ class Node(_common.Resource):
                 )
             else:
                 error_message = (
-                    "Cannot create a node with initial provision "
+                    f"Cannot create a node with initial provision "
                     f"state {expected_provision_state}"
                 )
                 # Nodes cannot be created as available using new API versions
@@ -343,7 +342,6 @@ class Node(_common.Resource):
                 )
                 microversion = self._assert_microversion_for(
                     session,
-                    'create',
                     microversion,
                     maximum=maximum,
                     error_message=error_message,
@@ -452,26 +450,26 @@ class Node(_common.Resource):
         """
         session = self._get_session(session)
 
-        version = None
+        microversion = None
         if target in _common.PROVISIONING_VERSIONS:
-            version = f'1.{_common.PROVISIONING_VERSIONS[target]}'
+            microversion = f'1.{_common.PROVISIONING_VERSIONS[target]}'
 
         if config_drive:
             # Some config drive actions require a higher version.
             if isinstance(config_drive, dict):
-                version = _common.CONFIG_DRIVE_DICT_VERSION
+                microversion = _common.CONFIG_DRIVE_DICT_VERSION
             elif target == 'rebuild':
-                version = _common.CONFIG_DRIVE_REBUILD_VERSION
+                microversion = _common.CONFIG_DRIVE_REBUILD_VERSION
 
         if deploy_steps:
-            version = _common.DEPLOY_STEPS_VERSION
+            microversion = _common.DEPLOY_STEPS_VERSION
 
-        version = self._assert_microversion_for(session, 'commit', version)
+        microversion = self._assert_microversion_for(session, microversion)
 
         body = {'target': target}
         if runbook:
-            version = self._assert_microversion_for(
-                session, 'commit', _common.RUNBOOKS_VERSION
+            microversion = self._assert_microversion_for(
+                session, _common.RUNBOOKS_VERSION
             )
 
             if clean_steps is not None:
@@ -546,7 +544,7 @@ class Node(_common.Resource):
             except KeyError:
                 raise ValueError(
                     f'For target {target} the expected state is not '
-                    'known, cannot wait for it'
+                    f'known, cannot wait for it'
                 )
 
         request = self._prepare_request(requires_id=True)
@@ -555,7 +553,7 @@ class Node(_common.Resource):
             request.url,
             json=body,
             headers=request.headers,
-            microversion=version,
+            microversion=microversion,
             retriable_status_codes=_common.RETRIABLE_STATUS_CODES,
         )
 
@@ -740,9 +738,7 @@ class Node(_common.Resource):
         """
         session = self._get_session(session)
         version = self._assert_microversion_for(
-            session,
-            'commit',
-            _common.INJECT_NMI_VERSION,
+            session, _common.INJECT_NMI_VERSION
         )
         request = self._prepare_request(requires_id=True)
         request.url = utils.urljoin(request.url, 'management', 'inject_nmi')
@@ -781,17 +777,17 @@ class Node(_common.Resource):
             except KeyError:
                 raise ValueError(
                     f"Cannot use target power state {target} with wait, "
-                    "the expected state is not known"
+                    f"the expected state is not known"
                 )
 
         session = self._get_session(session)
 
         if target.startswith("soft "):
-            version = '1.27'
+            microversion = '1.27'
         else:
-            version = None
+            microversion = None
 
-        version = self._assert_microversion_for(session, 'commit', version)
+        microversion = self._assert_microversion_for(session, microversion)
 
         # TODO(dtantsur): server timeout support
         body = {'target': target}
@@ -802,7 +798,7 @@ class Node(_common.Resource):
             request.url,
             json=body,
             headers=request.headers,
-            microversion=version,
+            microversion=microversion,
             retriable_status_codes=_common.RETRIABLE_STATUS_CODES,
         )
 
@@ -815,14 +811,108 @@ class Node(_common.Resource):
         if wait:
             self.wait_for_power_state(session, expected, timeout=timeout)
 
+    def attach_vmedia(
+        self,
+        session,
+        device_type,
+        image_url,
+        image_download_source=None,
+        retry_on_conflict=True,
+    ):
+        """Attach virtual media device to a node.
+
+        :param session: The session to use for making this request.
+        :type session: :class:`~keystoneauth1.adapter.Adapter`
+        :param device_type: The type of virtual media device.
+        :param image_url: The URL of the image to attach.
+        :param image_download_source: The source of the image download.
+        :param retry_on_conflict: Whether to retry HTTP CONFLICT errors.
+            This can happen when either the virtual media is already used on
+            a node or the node is locked. Since the latter happens more often,
+            the default value is True.
+        :return: ``None``
+        :raises: :exc:`~openstack.exceptions.NotSupported` if the server
+            does not support the VMEDIA API.
+
+        """
+        session = self._get_session(session)
+        version = self._assert_microversion_for(
+            session,
+            _common.VMEDIA_VERSION,
+            error_message=("Cannot use virtual media API"),
+        )
+        # Prepare the request and create the request body
+        request = self._prepare_request(requires_id=True)
+        request.url = utils.urljoin(request.url, 'vmedia')
+        body = {"device_type": device_type, "image_url": image_url}
+        if image_download_source:
+            body["image_download_source"] = image_download_source
+        retriable_status_codes = _common.RETRIABLE_STATUS_CODES
+        if not retry_on_conflict:
+            retriable_status_codes = list(set(retriable_status_codes) - {409})
+        response = session.post(
+            request.url,
+            json=body,
+            headers=request.headers,
+            microversion=version,
+            retriable_status_codes=retriable_status_codes,
+        )
+
+        msg = f"Failed to attach Virtual Media to bare metal node {self.id}"
+        exceptions.raise_from_response(response, error_message=msg)
+
+    def detach_vmedia(self, session, device_types=None):
+        """Detach virtual media from a node
+
+        :param session: The session to use for making this request.
+        :type session: :class:`~keystoneauth1.adapter.Adapter`
+        :param device_types: A list with the types of virtual media
+            devices to detach.
+        :return: ``True`` if the virtual media was detached,
+            otherwise ``False``.
+        :raises: :exc:`~openstack.exceptions.NotSupported` if the server
+            does not support the VMEDIA API
+        """
+        session = self._get_session(session)
+        version = self._assert_microversion_for(
+            session,
+            _common.VMEDIA_VERSION,
+            error_message=("Cannot use virtual media API"),
+        )
+
+        request = self._prepare_request(requires_id=True)
+        request.url = utils.urljoin(request.url, 'vmedia')
+
+        delete_kwargs = {
+            'headers': request.headers,
+            'microversion': version,
+            'retriable_status_codes': _common.RETRIABLE_STATUS_CODES,
+        }
+
+        if device_types:
+            delete_kwargs['json'] = {
+                'device_types': _common.comma_separated_list(device_types)
+            }
+
+        response = session.delete(request.url, **delete_kwargs)
+
+        if response.status_code == 400:
+            session.log.debug(
+                "Virtual media doesn't exist for node %(node)s",
+                {'node': self.id},
+            )
+
+        msg = f"Failed to detach virtual media from bare metal node {self.id}"
+        exceptions.raise_from_response(response, error_message=msg)
+
     def attach_vif(
         self,
         session: adapter.Adapter,
         vif_id: str,
         retry_on_conflict: bool = True,
         *,
-        port_id: ty.Optional[str] = None,
-        port_group_id: ty.Optional[str] = None,
+        port_id: str | None = None,
+        port_group_id: str | None = None,
     ) -> None:
         """Attach a VIF to the node.
 
@@ -856,13 +946,12 @@ class Node(_common.Resource):
 
         session = self._get_session(session)
         if port_id or port_group_id:
-            required_version = _common.VIF_OPTIONAL_PARAMS_VERSION
+            microversion = _common.VIF_OPTIONAL_PARAMS_VERSION
         else:
-            required_version = _common.VIF_VERSION
-        version = self._assert_microversion_for(
+            microversion = _common.VIF_VERSION
+        microversion = self._assert_microversion_for(
             session,
-            'commit',
-            required_version,
+            microversion,
             error_message=("Cannot use VIF attachment API"),
         )
 
@@ -880,7 +969,7 @@ class Node(_common.Resource):
             request.url,
             json=body,
             headers=request.headers,
-            microversion=version,
+            microversion=microversion,
             retriable_status_codes=retriable_status_codes,
         )
 
@@ -908,7 +997,6 @@ class Node(_common.Resource):
         session = self._get_session(session)
         version = self._assert_microversion_for(
             session,
-            'commit',
             _common.VIF_VERSION,
             error_message=("Cannot use VIF attachment API"),
         )
@@ -949,7 +1037,6 @@ class Node(_common.Resource):
         session = self._get_session(session)
         version = self._assert_microversion_for(
             session,
-            'fetch',
             _common.VIF_VERSION,
             error_message=("Cannot use VIF attachment API"),
         )
@@ -979,7 +1066,7 @@ class Node(_common.Resource):
             fails for a required interface.
         """
         session = self._get_session(session)
-        version = self._get_microversion(session, action='fetch')
+        version = self._get_microversion(session)
 
         request = self._prepare_request(requires_id=True)
         request.url = utils.urljoin(request.url, 'validate')
@@ -1034,7 +1121,7 @@ class Node(_common.Resource):
 
     def _do_maintenance_action(self, session, verb, body=None):
         session = self._get_session(session)
-        version = self._get_microversion(session, action='commit')
+        version = self._get_microversion(session)
         request = self._prepare_request(requires_id=True)
         request.url = utils.urljoin(request.url, 'maintenance')
         response = getattr(session, verb)(
@@ -1053,7 +1140,7 @@ class Node(_common.Resource):
         :returns: The HTTP response.
         """
         session = self._get_session(session)
-        version = self._get_microversion(session, action='fetch')
+        version = self._get_microversion(session)
         request = self._prepare_request(requires_id=True)
         request.url = utils.urljoin(request.url, 'management', 'boot_device')
 
@@ -1079,7 +1166,7 @@ class Node(_common.Resource):
         :returns: ``None``
         """
         session = self._get_session(session)
-        version = self._get_microversion(session, action='commit')
+        version = self._get_microversion(session)
         request = self._prepare_request(requires_id=True)
         request.url = utils.urljoin(request.url, 'management', 'boot_device')
 
@@ -1103,7 +1190,7 @@ class Node(_common.Resource):
         :returns: The HTTP response.
         """
         session = self._get_session(session)
-        version = self._get_microversion(session, action='fetch')
+        version = self._get_microversion(session)
         request = self._prepare_request(requires_id=True)
         request.url = utils.urljoin(
             request.url,
@@ -1144,7 +1231,7 @@ class Node(_common.Resource):
         if target not in ('uefi', 'bios'):
             raise ValueError(
                 f"Unrecognized boot mode {target}."
-                "Boot mode should be one of 'uefi' or 'bios'."
+                f"Boot mode should be one of 'uefi' or 'bios'."
             )
         body = {'target': target}
 
@@ -1180,7 +1267,7 @@ class Node(_common.Resource):
         if not isinstance(target, bool):
             raise ValueError(
                 f"Invalid target {target}. It should be True or False "
-                "corresponding to secure boot state 'on' or 'off'"
+                f"corresponding to secure boot state 'on' or 'off'"
             )
         body = {'target': target}
 
@@ -1301,7 +1388,7 @@ class Node(_common.Resource):
         :returns: The HTTP response.
         """
         session = self._get_session(session)
-        version = self._get_microversion(session, action='commit')
+        version = self._get_microversion(session)
         request = self._prepare_request(requires_id=True)
         request.url = utils.urljoin(
             request.url, f'vendor_passthru?method={method}'
@@ -1331,7 +1418,7 @@ class Node(_common.Resource):
         :returns: The HTTP response.
         """
         session = self._get_session(session)
-        version = self._get_microversion(session, action='fetch')
+        version = self._get_microversion(session)
         request = self._prepare_request(requires_id=True)
         request.url = utils.urljoin(request.url, 'vendor_passthru/methods')
 
@@ -1354,7 +1441,7 @@ class Node(_common.Resource):
         :returns: The HTTP response.
         """
         session = self._get_session(session)
-        version = self._get_microversion(session, action='fetch')
+        version = self._get_microversion(session)
         request = self._prepare_request(requires_id=True)
         request.url = utils.urljoin(request.url, 'states', 'console')
 
@@ -1378,13 +1465,13 @@ class Node(_common.Resource):
         :return: ``None``
         """
         session = self._get_session(session)
-        version = self._get_microversion(session, action='commit')
+        version = self._get_microversion(session)
         request = self._prepare_request(requires_id=True)
         request.url = utils.urljoin(request.url, 'states', 'console')
         if not isinstance(enabled, bool):
             raise ValueError(
                 f"Invalid enabled {enabled}. It should be True or False "
-                "corresponding to console enabled or disabled"
+                f"corresponding to console enabled or disabled"
             )
         body = {'enabled': enabled}
 
@@ -1413,7 +1500,7 @@ class Node(_common.Resource):
                 os_warnings.RemovedInSDK60Warning,
             )
         session = self._get_session(session)
-        version = self._get_microversion(session, action='fetch')
+        version = self._get_microversion(session)
         request = self._prepare_request(requires_id=True)
         request.url = utils.urljoin(request.url, 'inventory')
 
@@ -1437,7 +1524,6 @@ class Node(_common.Resource):
         session = self._get_session(session)
         version = self._assert_microversion_for(
             session,
-            'fetch',
             _common.FIRMWARE_VERSION,
             error_message=("Cannot use node list firmware components API"),
         )
@@ -1482,7 +1568,7 @@ class Node(_common.Resource):
 
             session = self._get_session(session)
             microversion = self._assert_microversion_for(
-                session, 'commit', _common.RESET_INTERFACES_VERSION
+                session, _common.RESET_INTERFACES_VERSION
             )
             params = [('reset_interfaces', reset_interfaces)]
 
