@@ -10,15 +10,63 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import typing as ty
+import warnings
+
 from openstack.cloud import _utils
 from openstack.cloud import openstackcloud
 from openstack import exceptions
 from openstack import utils
+from openstack import warnings as os_warnings
+
+if ty.TYPE_CHECKING:
+    import concurrent.futures
+    from keystoneauth1 import session as ks_session
+    from oslo_config import cfg
+
+    from openstack.config import cloud_region
+    from openstack import service_description
 
 
 class ImageCloudMixin(openstackcloud._OpenStackCloudMixin):
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
+    def __init__(
+        self,
+        cloud: str | None = None,
+        config: ty.Optional['cloud_region.CloudRegion'] = None,
+        session: ty.Optional['ks_session.Session'] = None,
+        app_name: str | None = None,
+        app_version: str | None = None,
+        extra_services: list['service_description.ServiceDescription']
+        | None = None,
+        strict: bool = False,
+        use_direct_get: bool | None = None,
+        task_manager: ty.Any = None,
+        rate_limit: float | dict[str, float] | None = None,
+        oslo_conf: ty.Optional['cfg.ConfigOpts'] = None,
+        service_types: list[str] | None = None,
+        global_request_id: str | None = None,
+        strict_proxies: bool = False,
+        pool_executor: ty.Optional['concurrent.futures.Executor'] = None,
+        **kwargs: ty.Any,
+    ):
+        super().__init__(
+            cloud=cloud,
+            config=config,
+            session=session,
+            app_name=app_name,
+            app_version=app_version,
+            extra_services=extra_services,
+            strict=strict,
+            use_direct_get=use_direct_get,
+            task_manager=task_manager,
+            rate_limit=rate_limit,
+            oslo_conf=oslo_conf,
+            service_types=service_types,
+            global_request_id=global_request_id,
+            strict_proxies=strict_proxies,
+            pool_executor=pool_executor,
+            **kwargs,
+        )
 
         self.image_api_use_tasks = self.config.config['image_api_use_tasks']
 
@@ -69,10 +117,26 @@ class ImageCloudMixin(openstackcloud._OpenStackCloudMixin):
             OR
             A string containing a jmespath expression for further filtering.
             Example:: "[?last_name==`Smith`] | [?other.gender]==`Female`]"
-
         :returns: An image :class:`openstack.image.v2.image.Image` object.
         """
-        return _utils._get_entity(self, 'image', name_or_id, filters)
+        if filters is not None:
+            warnings.warn(
+                "The 'filters' argument is deprecated; use 'search_images' "
+                "instead",
+                os_warnings.RemovedInSDK60Warning,
+            )
+            entities = self.search_images(name_or_id, filters)
+            if not entities:
+                return None
+
+            if len(entities) > 1:
+                raise exceptions.SDKException(
+                    f"Multiple matches found for {name_or_id}",
+                )
+
+            return entities[0]
+
+        return self.image.find_image(name_or_id)
 
     def get_image_by_id(self, id):
         """Get a image by ID
@@ -88,6 +152,7 @@ class ImageCloudMixin(openstackcloud._OpenStackCloudMixin):
         output_path=None,
         output_file=None,
         chunk_size=1024 * 1024,
+        stream=False,
     ):
         """Download an image by name or ID
 
@@ -99,6 +164,7 @@ class ImageCloudMixin(openstackcloud._OpenStackCloudMixin):
             this or output_path must be specified
         :param int chunk_size: size in bytes to read from the wire and buffer
             at one time. Defaults to 1024 * 1024 = 1 MiB
+        :param: bool stream: whether to stream the output in chunk_size.
 
         :returns: When output_path and output_file are not given - the bytes
             comprising the given Image when stream is False, otherwise a
@@ -125,7 +191,10 @@ class ImageCloudMixin(openstackcloud._OpenStackCloudMixin):
         image = self.image.find_image(name_or_id, ignore_missing=False)
 
         return self.image.download_image(
-            image, output=output_file or output_path, chunk_size=chunk_size
+            image,
+            output=output_file or output_path,
+            chunk_size=chunk_size,
+            stream=stream,
         )
 
     def get_image_exclude(self, name_or_id, exclude):
