@@ -10,12 +10,11 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from openstack.common import tag
 from openstack.network.v2 import _base
 from openstack import resource
 
 
-class Port(_base.NetworkResource, tag.TagMixin):
+class Port(_base.NetworkResource, _base.TagMixinNetwork):
     resource_key = 'port'
     resources_key = 'ports'
     base_path = '/ports'
@@ -48,10 +47,12 @@ class Port(_base.NetworkResource, tag.TagMixin):
         'subnet_id',
         'project_id',
         'security_groups',
+        'sort_key',
+        'sort_dir',
         is_admin_state_up='admin_state_up',
         is_port_security_enabled='port_security_enabled',
         security_group_ids='security_groups',
-        **tag.TagMixin._tag_query_parameters
+        **_base.TagMixinNetwork._tag_query_parameters,
     )
 
     # Properties
@@ -159,5 +160,8 @@ class Port(_base.NetworkResource, tag.TagMixin):
     #: sub_ports is a list of dicts with keys:
     #: port_id, segmentation_type, segmentation_id, mac_address*
     trunk_details = resource.Body('trunk_details', type=dict)
+    #: Status of the trusted VIF setting, this value is added to the
+    #: binding:profile field and passed to services which needs, it, like Nova
+    trusted = resource.Body('trusted', type=bool)
     #: Timestamp when the port was last updated.
     updated_at = resource.Body('updated_at')
