@@ -9,6 +9,12 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+
+import typing as ty
+
+from keystoneauth1 import adapter
+import typing_extensions as ty_ext
+
 from openstack.common import tag
 from openstack import exceptions
 from openstack import resource
@@ -36,7 +42,7 @@ class Stack(resource.Resource):
         'owner_id',
         'username',
         project_id='tenant_id',
-        **tag.TagMixin._tag_query_parameters
+        **tag.TagMixin._tag_query_parameters,
     )
 
     # Properties
@@ -112,40 +118,37 @@ class Stack(resource.Resource):
     #: The ID of the user project created for this stack.
     user_project_id = resource.Body('stack_user_project_id')
 
-    def create(self, session, base_path=None):
+    def create(self, session, prepend_key=False, *args, **kwargs):
         # This overrides the default behavior of resource creation because
         # heat doesn't accept resource_key in its request.
-        return super(Stack, self).create(
-            session, prepend_key=False, base_path=base_path
-        )
+        return super().create(session, prepend_key, *args, **kwargs)
 
-    def commit(self, session, base_path=None):
-        # This overrides the default behavior of resource creation because
-        # heat doesn't accept resource_key in its request.
-        return super(Stack, self).commit(
-            session, prepend_key=False, has_body=False, base_path=None
-        )
-
-    def update(self, session, preview=False):
+    def commit(
+        self,
+        session,
+        prepend_key=True,
+        has_body=True,
+        retry_on_conflict=None,
+        base_path=None,
+        *,
+        microversion=None,
+        preview=False,
+        **kwargs,
+    ):
         # This overrides the default behavior of resource update because
         # we need to use other endpoint for update preview.
         base_path = None
         if self.name and self.id:
-            base_path = '/stacks/%(stack_name)s/%(stack_id)s' % {
-                'stack_name': self.name,
-                'stack_id': self.id,
-            }
+            base_path = f'/stacks/{self.name}/{self.id}'
         elif self.name or self.id:
             # We have only one of name/id. Do not try to build a stacks/NAME/ID
             # path
-            base_path = '/stacks/%(stack_identity)s' % {
-                'stack_identity': self.name or self.id
-            }
+            base_path = f'/stacks/{self.name or self.id}'
         request = self._prepare_request(
             prepend_key=False, requires_id=False, base_path=base_path
         )
 
-        microversion = self._get_microversion(session, action='commit')
+        microversion = self._get_microversion(session)
 
         request_url = request.url
         if preview:
@@ -217,7 +220,9 @@ class Stack(resource.Resource):
         base_path=None,
         error_message=None,
         skip_cache=False,
+        *,
         resolve_outputs=True,
+        **params,
     ):
         if not self.allow_fetch:
             raise exceptions.MethodNotSupported(self, "fetch")
@@ -226,7 +231,7 @@ class Stack(resource.Resource):
             requires_id=requires_id, base_path=base_path
         )
         # session = self._get_session(session)
-        microversion = self._get_microversion(session, action='fetch')
+        microversion = self._get_microversion(session)
 
         # NOTE(gtema): would be nice to simply use QueryParameters, however
         # Heat return 302 with parameters being set into URL and requests
@@ -244,13 +249,65 @@ class Stack(resource.Resource):
         self._translate_response(response, **kwargs)
 
         if self and self.status in ['DELETE_COMPLETE', 'ADOPT_COMPLETE']:
-            raise exceptions.ResourceNotFound(
-                "No stack found for %s" % self.id
-            )
+            raise exceptions.NotFoundException(f"No stack found for {self.id}")
         return self
 
+    @ty.overload
     @classmethod
-    def find(cls, session, name_or_id, ignore_missing=True, **params):
+    def find(
+        cls,
+        session: adapter.Adapter,
+        name_or_id: str,
+        ignore_missing: ty.Literal[True] = True,
+        list_base_path: str | None = None,
+        *,
+        microversion: str | None = None,
+        all_projects: bool | None = None,
+        **params: ty.Any,
+    ) -> ty_ext.Self | None: ...
+
+    @ty.overload
+    @classmethod
+    def find(
+        cls,
+        session: adapter.Adapter,
+        name_or_id: str,
+        ignore_missing: ty.Literal[False],
+        list_base_path: str | None = None,
+        *,
+        microversion: str | None = None,
+        all_projects: bool | None = None,
+        **params: ty.Any,
+    ) -> ty_ext.Self: ...
+
+    # excuse the duplication here: it's mypy's fault
+    # https://github.com/python/mypy/issues/14764
+    @ty.overload
+    @classmethod
+    def find(
+        cls,
+        session: adapter.Adapter,
+        name_or_id: str,
+        ignore_missing: bool,
+        list_base_path: str | None = None,
+        *,
+        microversion: str | None = None,
+        all_projects: bool | None = None,
+        **params: ty.Any,
+    ) -> ty_ext.Self | None: ...
+
+    @classmethod
+    def find(
+        cls,
+        session: adapter.Adapter,
+        name_or_id: str,
+        ignore_missing: bool = True,
+        list_base_path: str | None = None,
+        *,
+        microversion: str | None = None,
+        all_projects: bool | None = None,
+        **params: ty.Any,
+    ) -> ty_ext.Self | None:
         """Find a resource by its name or id.
 
         :param session: The session to use for making this request.
@@ -258,7 +315,7 @@ class Stack(resource.Resource):
         :param name_or_id: This resource's identifier, if needed by
                            the request. The default is ``None``.
         :param bool ignore_missing: When set to ``False``
-                    :class:`~openstack.exceptions.ResourceNotFound` will be
+                    :class:`~openstack.exceptions.NotFoundException` will be
                     raised when the resource does not exist.
                     When set to ``True``, None will be returned when
                     attempting to find a nonexistent resource.
@@ -271,14 +328,16 @@ class Stack(resource.Resource):
                  or None if nothing matches.
         :raises: :class:`openstack.exceptions.DuplicateResource` if more
                  than one resource is found for this request.
-        :raises: :class:`openstack.exceptions.ResourceNotFound` if nothing
+        :raises: :class:`openstack.exceptions.NotFoundException` if nothing
                  is found and ignore_missing is ``False``.
         """
         session = cls._get_session(session)
         # Try to short-circuit by looking directly for a matching ID.
         try:
             match = cls.existing(
-                id=name_or_id, connection=session._get_connection(), **params
+                id=name_or_id,
+                connection=session._get_connection(),  # type: ignore
+                **params,
             )
             return match.fetch(session, **params)
         except exceptions.NotFoundException:
@@ -289,8 +348,9 @@ class Stack(resource.Resource):
 
         if ignore_missing:
             return None
-        raise exceptions.ResourceNotFound(
-            "No %s found for %s" % (cls.__name__, name_or_id)
+
+        raise exceptions.NotFoundException(
+            f"No {cls.__name__} found for {name_or_id}"
         )
 
 
