@@ -20,13 +20,13 @@ from openstack.tests.functional import base
 class TestRouterInterface(base.BaseFunctionalTest):
     CIDR = "10.100.0.0/16"
     IPV4 = 4
-    ROUTER_ID = None
-    NET_ID = None
-    SUB_ID = None
-    ROT = None
+    ROUTER_ID: str
+    NET_ID: str
+    SUB_ID: str
+    ROT: router.Router
 
     def setUp(self):
-        super(TestRouterInterface, self).setUp()
+        super().setUp()
         self.ROUTER_NAME = self.getUniqueString()
         self.NET_NAME = self.getUniqueString()
         self.SUB_NAME = self.getUniqueString()
@@ -62,7 +62,7 @@ class TestRouterInterface(base.BaseFunctionalTest):
             self.NET_ID, ignore_missing=False
         )
         self.assertIsNone(sot)
-        super(TestRouterInterface, self).tearDown()
+        super().tearDown()
 
     def test_router_add_remove_interface(self):
         iface = self.ROT.add_interface(
