@@ -14,12 +14,13 @@ from openstack.key_manager.v1 import _proxy
 from openstack.key_manager.v1 import container
 from openstack.key_manager.v1 import order
 from openstack.key_manager.v1 import secret
+from openstack.key_manager.v1 import secret_store
 from openstack.tests.unit import test_proxy_base
 
 
 class TestKeyManagerProxy(test_proxy_base.TestProxyBase):
     def setUp(self):
-        super(TestKeyManagerProxy, self).setUp()
+        super().setUp()
         self.proxy = _proxy.Proxy(self.session)
 
 
@@ -97,3 +98,8 @@ class TestKeyManagerSecret(TestKeyManagerProxy):
 
     def test_secret_update(self):
         self.verify_update(self.proxy.update_secret, secret.Secret)
+
+
+class TestKeyManagerSecretStore(TestKeyManagerProxy):
+    def test_secret_stores(self):
+        self.verify_list(self.proxy.secret_stores, secret_store.SecretStore)
